Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2627)

Unified Diff: content/renderer/render_thread_impl.h

Issue 1960803002: Split the media context from the compositor worker context. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/render_thread_impl.h
diff --git a/content/renderer/render_thread_impl.h b/content/renderer/render_thread_impl.h
index 806d32bfbd261725bf64de15bf2db7ae1358d6c4..e6306789cc868a11a94a1a17082826e7dd474b4f 100644
--- a/content/renderer/render_thread_impl.h
+++ b/content/renderer/render_thread_impl.h
@@ -339,8 +339,10 @@ class CONTENT_EXPORT RenderThreadImpl
// A TaskRunner instance that runs tasks on the raster worker pool.
base::TaskRunner* GetWorkerTaskRunner();
- // Returns a shared worker context provider that can be used on any thread.
- scoped_refptr<ContextProviderCommandBuffer> SharedWorkerContextProvider();
+ // Returns a worker context provider that will be bound on the compositor
+ // thread.
+ scoped_refptr<ContextProviderCommandBuffer>
+ SharedCompositorWorkerContextProvider();
// Causes the idle handler to skip sending idle notifications
// on the two next scheduled calls, so idle notifications are

Powered by Google App Engine
This is Rietveld 408576698